@@ -39,6 +39,7 @@ class AkinonCloudClient:
         "project_app_deployment_log": "projects/{p_id}/project_apps/{pa_id}/deployments/{deployment_id}/logs",
         "project_apps_logs": "projects/{project_id}/project_apps/{project_app_id}/logs/",
         "project_apps_export_logs": "projects/{project_id}/project_apps/{project_app_id}/logs/export",
+        "relatable_project_apps": "projects/{project_id}/applications/{app_id}/relatable-project-apps/",
         "public_keys": "users/public_keys/",
         "public_key_detail": "users/public_keys/{pk_id}/",
         "register": "users/register/",
@@ -178,6 +179,9 @@ class AkinonCloudClient:
             "POST", "project_apps_logs", params={"project_id": project_id, "project_app_id": project_app_id}, data=data
         )
 
+    def get_relatable_project_apps(self, app_id, project_id):
+        return self._send_request("GET", "relatable_project_apps", params={"project_id": project_id, "app_id": app_id})
+
     def export_project_app_logs(
         self, project_id, project_app_id, start_date=None, end_date=None, dates=None, applications=None
     ):
