@@ -1,7 +1,7 @@
 import os
 from datetime import datetime, timedelta, timezone
 
-from cement import Controller, ex
+from cement import Controller, ex, shell
 from cement.utils.version import get_version_banner
 
 from ..core.exc import AkinonCLIError, AkinonCLIWarning
@@ -313,6 +313,26 @@ class ProjectApps(Controller):
         p_id = self.app.pargs.project_id
         app_id = self.app.pargs.app_id
         data = {'app': app_id}
+        response = self.app.client.get_relatable_project_apps(app_id=app_id, project_id=p_id)
+        if response.is_succeed and response.data:
+            app = response.data[0]['app']
+            project_apps = response.data[0]['project_apps']
+            if not project_apps:
+                self.app.render(
+                    f"App needs a {app['name']} app. Please install a {app['name']} first.", renderer_type='text'
+                )
+                return
+
+            print(f"This application needs to be related with a {app['name']}.")
+            options = []
+            for project_app in project_apps:
+                options.append(str(project_app['pk']))
+                print(f"{project_app['pk']} - {project_app['name']}")
+
+            p = shell.Prompt(f"Enter one of your project app id or exit with (control + c)", options=options)
+            child_project_app = p.prompt()
+            data.update(extra_data={"child_project_app": child_project_app})
+
         response = self.app.client.create_project_app(p_id, data)
         if response.is_succeed:
             self.app.render("App has been added to the project.", renderer_type='text')
